@@ -2,6 +2,9 @@ import sys
 import click
 from ..util import to_table
 from .. import Cloudscale, CloudscaleApiException, CloudscaleException
+from . import _init, _list
+
+headers = ['zones', 'slug']
 
 @click.group()
 @click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
@@ -9,21 +12,18 @@ from .. import Cloudscale, CloudscaleApiException, CloudscaleException
 @click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
 def region(ctx, profile, api_token, verbose):
-    try:
-        ctx.obj = Cloudscale(api_token, profile, verbose)
-    except CloudscaleException as e:
-        click.echo(e, err=True)
-        sys.exit(1)
+    _init(
+        ctx=ctx,
+        api_token=api_token,
+        profile=profile,
+        verbose=verbose,
+    )
 
 @region.command("list")
 @click.pass_obj
 def cmd_list(cloudscale):
-    try:
-        response = cloudscale.region.get_all()
-        if response:
-            headers = ['zones', 'slug']
-            table = to_table(response, headers)
-            click.echo(table)
-    except CloudscaleApiException as e:
-        click.echo(e, err=True)
-        sys.exit(1)
+    resource = cloudscale.region
+    _list(
+        resource=resource,
+        headers=headers,
+    )
