@@ -50,3 +50,11 @@ def test_region_get_all():
         'list',
     ])
     assert result.exit_code > 0
+
+def test_region_missing_api_key():
+    runner = CliRunner()
+    result = runner.invoke(cli, [
+        'region',
+        'list',
+    ])
+    assert result.exit_code == 1
